#
# spec file for package aide
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           aide
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  curl-devel
BuildRequires:  flex
BuildRequires:  libacl-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libselinux-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
Version:        0.16
Release:        24.1
Summary:        Advanced Intrusion Detection Environment
License:        GPL-2.0+
Group:          Productivity/Security
Source0:        https://downloads.sourceforge.net/project/aide/aide/%version/aide-%version.tar.gz
Source42:       https://downloads.sourceforge.net/project/aide/aide/%version/aide-%version.tar.gz.asc
Source43:       aide.keyring
Source1:        aide.conf
Source2:        aide-cron_daily.sh
Source3:        aide-test.sh
Patch1:         aide-%{version}-as-needed.patch
Patch3:         aide-xattr-in-libc.patch
Patch4:         aide-dynamic.patch
Patch5:		aide-define_hash_use_gcrypt.patch
Patch6:		aide-0.15-syslog-format.patch
Patch7:         aide-disable-gcrypt-MD5-in-fips-mode.patch
Patch8:         aide-0.16-cve-2021-45417.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://sourceforge.net/projects/aide/

%description
AIDE is an intrusion detection system that checks file integrity.

%package test
Summary:        Simple AIDE testing
Group:          Productivity/Security

%description test
Simple AIDE test script for externalized testing.

%prep
%setup -q
%patch1 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

%build
autoreconf -fiv
%configure 					\
	--with-config_file=/etc/aide.conf	\
	--with-dbhmactype=md5			\
	--disable-static			\
	--enable-lfs				\
	--with-posix-acl			\
	--with-xattr				\
	--with-selinux				\
	--with-curl				\
	--with-zlib \
    --with-gcrypt \
    --without-mhash
# --enable-forced_configmd
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
install -m 700 -d     $RPM_BUILD_ROOT/var/lib/aide
install -m 700 -d     $RPM_BUILD_ROOT/etc
install -m 600 %{S:1} $RPM_BUILD_ROOT/etc/aide.conf
install -m 700 %{S:3} $RPM_BUILD_ROOT/usr/bin/
mkdir -p doc/examples/etc/cron.daily/
cp -a %{S:2} doc/examples/etc/cron.daily/aide.sh

%check
mkdir /var/tmp/aide-test
export TESTDIR=/var/tmp/aide-test
make DESTDIR=$TESTDIR install
install -m 700 -d $TESTDIR/var/lib/aide
install -m 700 -d $TESTDIR/etc
install -m 600    %{S:1} $TESTDIR/etc/aide.conf.new
sed -e "s#/var/lib/aide#$TESTDIR/var/lib/aide#g" <$TESTDIR/etc/aide.conf.new >$TESTDIR/etc/aide.conf
sleep 2
sync
sleep 2

$TESTDIR/usr/bin/aide -c $TESTDIR/etc/aide.conf --init
mv $TESTDIR/var/lib/aide/aide.db.new $TESTDIR/var/lib/aide/aide.db
$TESTDIR/usr/bin/aide -c $TESTDIR/etc/aide.conf --check --verbose

rm -rf $TESTDIR

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README doc/manual* aide.* doc/examples
%{_prefix}/bin/aide
/%{_mandir}/man1/aide.1.gz
/%{_mandir}/man5/aide.conf.5.gz
/var/lib/aide
%config(noreplace) /etc/aide.conf

%files test
%defattr(-,root,root)
/usr/bin/aide-test.sh

%changelog
* Mon Jan 17 2022 meissner@suse.com
- aide-0.16-cve-2021-45417.patch: Fix a bufferoverflow in base64
  functions (bsc#1194735 CVE-2021-45417)
* Wed Nov 24 2021 ali.abdallah@suse.com
- aide-disable-gcrypt-MD5-in-fips-mode.patch: gcrypt aborts if MD5
  is used in fips mode, so disable it also in aide (bsc#1191422).
* Thu Jan  7 2021 meissner@suse.com
- aide-0.15-syslog-format.patch: Add a syslog_format to aide (bsc#1180165)
* Thu Jul 11 2019 abergmann@suse.com
- Remove not available gcrypt algorithm 7 DB_HAVAL (bsc#1098360).
  Add aide-define_hash_use_gcrypt.patch
* Wed Jan 18 2017 meissner@suse.com
- Updated to 0.16
  - lots of bugfixes
  - including regexp matching within subdirectories of expressions
- aide-0.16-as-needed.patch: replaces aide-0.15.1-as-needed.patch
- aide-no_m4_dir.patch: upstream
- aide.keyring: added from keyserver, cross checked key id on
  http://aide.sourceforge.net/ and a signature from someone
  I signed.
* Thu Jul  2 2015 meissner@suse.com
- aide-dynamic.patch: avoid overwriting dl* functions, as we might
  load libcrypto.so dynamically in FIPS mode.
* Wed May 28 2014 crrodriguez@opensuse.org
- aide-xattr-in-libc.patch: Once upon a time, 10 years ago, basic extended
  attribute functionality moved to libc, therefore libattr is most of the
  time, not needed at all.
* Thu Jan 23 2014 meissner@suse.com
- seperate a -test package to help with externalized testing.
* Wed Jan 15 2014 meissner@suse.com
- aide.conf: Move from md5 and sha1 as default to sha256+sha512, also
  to allow FIPS enabling with aide working. FATE#315925
* Fri Apr 26 2013 mmeister@suse.com
- Removed AC_CONFIG_MACRO_DIR([m4]) from configure.in to fix
  build with new automake: aide-no_m4_dir.patch
* Wed Jan  4 2012 crrodriguez@opensuse.org
- libmhash development was abandoned in 2007, so it is time
  for it to go into the library heaven, use libgcrypt instead.
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Add missing call to make
- Use %%_smp_mflags for parallel build
* Fri Oct  1 2010 freespacer@gmx.de
- updated to version 0.15.1
  - Ignore changed file name if attributes does not match
  - Allow absence of DB_CHECKINODE if file name has changed
- renew patch
* Tue Aug 10 2010 meissner@suse.de
- updated to 0.15
  - lots of fixes and some new stuff
* Thu Apr 29 2010 ro@suse.de
- make aide check verbose to get started
- add sleep and sync to fix build
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Jun 17 2009 crrodriguez@suse.de
- fix build when as-needed is a default liker option
* Mon Jan  5 2009 meissner@suse.de
- fixed abort on check/update by removing the hash requirement bnc#406597
- fixed version output bnc#463511
- enhanced testcase to also run one aide --check
* Fri Aug 22 2008 meissner@suse.de
- enabled SELinux support [Fate#303662]
- enabled curl
- disable static (does not make much sense)
* Tue Feb 12 2008 meissner@suse.de
- Version 0.13.1
  * Fixed bug with reading gzipped aide.db files
  * Removed dead ustat code
- Version 0.13
  * Added support for selinux and xattr attributes
    (kindly contributed by Red Hat)
  * Added support for the Linux Audit System
    (kindly contributed by Red Hat)
  * Fixed usage of libgcrypt instead of libmhash
  * Added file locking for output files
  * Fixed bugs
- Version 0.12
  * Fixed bugs
  * Allow http/https/ftp URLs through libcurl
  * Support posix_fadvice() to avoid caching files
- enabled ACL and XATTR support
* Thu Mar 29 2007 meissner@suse.de
- buildrequires flex,bison
* Thu Apr 13 2006 meissner@suse.de
- run aide --init as test
* Mon Feb 20 2006 mge@suse.de
- update to 0.11
- fixes bug #149059
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Fri Mar 18 2005 mge@suse.de
- fixes #71272 - aide-0.10-47 config files not yet converted to utf8
* Mon Jan 26 2004 mge@suse.de
- upgrade to 0.10
- #33600: more usable default aide.conf
  (thanks to Dirk Mueller <dmuell@gmx.net>)
- example-cron-job
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Nov 13 2002 ro@suse.de
- fix build for current bison
* Thu Aug 15 2002 mge@suse.de
- update to 0.9
* Mon Apr  9 2001 ro@suse.de
- don't use macro for version
- remove obsolete macros
* Wed Nov 22 2000 mge@suse.de
- created PAC files
- make SPEC file 7.0 compliant
* Sat Jul 15 2000 mge@suse.de
- initial SuSE RPM, config file /etc/aide.conf
* Tue Jan 25 2000 weejock@ferret.lmh.ox.ac.uk
- Fixes for RH 6.1 and sysconfdir changed to /etc and /var/lib/aide added
* Sat Sep 11 1999 rammer@cs.tut.fi
- Some small changes to make this autogeneratable by configure.
* Fri Sep 10 1999 zab@redhat.com
- First go
